@@ -1,7 +1,7 @@
 """
 Esmerald: Highly scalable, performant, easy to learn and for every application.
 """
-__version__ = "0.6.0"
+__version__ = "0.11.0"
 
 from starlette import status
 
@@ -11,16 +11,8 @@ from esmerald.injector import Inject
 
 from .applications import ChildEsmerald, Esmerald
 from .backgound import BackgroundTask, BackgroundTasks
-from .config import (
-    CORSConfig,
-    CSRFConfig,
-    JWTConfig,
-    OpenAPIConfig,
-    SessionConfig,
-    StaticFilesConfig,
-    TemplateConfig,
-)
-from .datastructures import UploadFile
+from .config import CORSConfig, CSRFConfig, OpenAPIConfig, SessionConfig, StaticFilesConfig
+from .datastructures import JSON, Redirect, Stream, Template, UploadFile
 from .exceptions import (
     HTTPException,
     ImproperlyConfigured,
@@ -32,17 +24,16 @@ from .exceptions import (
     ValidationErrorException,
 )
 from .interceptors.interceptor import EsmeraldInterceptor
-from .params import Body, Cookie, Header, Injects, Param, Path, Query
+from .param_functions import DirectInjects
+from .params import Body, Cookie, File, Form, Header, Injects, Param, Path, Query
 from .permissions import AllowAny, BasePermission, DenyAll
 from .protocols import AsyncDAOProtocol, DaoProtocol, MiddlewareProtocol
 from .requests import Request
-from .responses import JSONResponse, ORJSONResponse, Response, TemplateResponse, UJSONResponse
+from .responses import JSONResponse, Response, TemplateResponse
 from .routing.gateways import Gateway, WebSocketGateway
 from .routing.handlers import delete, get, patch, post, put, route, websocket
 from .routing.router import Include, Router
 from .routing.views import APIView
-from .schedulers.asyncz.handler import scheduler
-from .template import JinjaTemplateEngine, MakoTemplateEngine
 from .websockets import WebSocket, WebSocketDisconnect
 
 __all__ = [
@@ -59,9 +50,12 @@ __all__ = [
     "Cookie",
     "DaoProtocol",
     "DenyAll",
+    "DirectInjects",
     "Esmerald",
     "EsmeraldAPISettings",
     "EsmeraldInterceptor",
+    "File",
+    "Form",
     "Gateway",
     "Header",
     "HTTPException",
@@ -69,29 +63,27 @@ __all__ = [
     "Inject",
     "Injects",
     "ImproperlyConfigured",
+    "JSON",
     "JSONResponse",
-    "JinjaTemplateEngine",
-    "JWTConfig",
-    "MakoTemplateEngine",
     "MethodNotAllowed",
     "MiddlewareProtocol",
     "NotAuthenticated",
     "NotFound",
-    "ORJSONResponse",
     "OpenAPIConfig",
     "Param",
     "Path",
     "PermissionDenied",
     "Query",
+    "Redirect",
     "Request",
     "Response",
     "Router",
     "ServiceUnavailable",
     "SessionConfig",
     "StaticFilesConfig",
-    "TemplateConfig",
+    "Stream",
+    "Template",
     "TemplateResponse",
-    "UJSONResponse",
     "UploadFile",
     "ValidationErrorException",
     "WebSocket",
@@ -103,7 +95,6 @@ __all__ = [
     "post",
     "put",
     "route",
-    "scheduler",
     "settings",
     "status",
     "websocket",
