@@ -1,22 +1,14 @@
 from typing import TYPE_CHECKING, Any, AsyncContextManager, Callable, Dict, List, Optional, Union
 
 from openapi_schemas_pydantic.v3_1_0 import License, SecurityRequirement, Server
-from pydantic import BaseSettings
+from pydantic import BaseConfig, BaseSettings
 
 from esmerald import __version__
 from esmerald.conf.enums import EnvironmentType
-from esmerald.config import (
-    CORSConfig,
-    CSRFConfig,
-    OpenAPIConfig,
-    SessionConfig,
-    StaticFilesConfig,
-    TemplateConfig,
-)
+from esmerald.config import CORSConfig, CSRFConfig, OpenAPIConfig, SessionConfig, StaticFilesConfig
 from esmerald.config.asyncexit import AsyncExitConfig
 from esmerald.interceptors.types import Interceptor
 from esmerald.permissions.types import Permission
-from esmerald.schedulers import AsyncIOScheduler
 from esmerald.types import (
     APIGateHandler,
     Dependencies,
@@ -31,6 +23,7 @@ from esmerald.types import (
 
 if TYPE_CHECKING:
     from esmerald.applications import Esmerald
+    from esmerald.types import TemplateConfig
 
 
 class EsmeraldAPISettings(BaseSettings):
@@ -55,7 +48,6 @@ class EsmeraldAPISettings(BaseSettings):
     response_class: Optional[ResponseType] = None
     response_cookies: Optional[ResponseCookies] = None
     response_headers: Optional[ResponseHeaders] = None
-    scheduler_class: SchedulerType = AsyncIOScheduler
     include_in_schema: bool = True
     tags: Optional[List[str]] = None
     timezone: str = "UTC"
@@ -66,6 +58,9 @@ class EsmeraldAPISettings(BaseSettings):
     enable_openapi: bool = True
     redirect_slashes: bool = True
 
+    class Config(BaseConfig):
+        extra = "allow"
+
     @property
     def reload(self) -> bool:
         """
@@ -143,7 +138,7 @@ class EsmeraldAPISettings(BaseSettings):
         return AsyncExitConfig()
 
     @property
-    def template_config(self) -> TemplateConfig:
+    def template_config(self) -> "TemplateConfig":
         """
         Initial Default configuration for the TemplateConfig.
         This can be overwritten in another setting or simply override `template_config` or then override
@@ -159,7 +154,7 @@ class EsmeraldAPISettings(BaseSettings):
 
             class MySettings(EsmeraldAPISettings):
                 @property
-                def template_config(self) -> TemplateConfig:
+                def template_config(self) -> "TemplateConfig":
                     TemplateConfig(directory='templates', engine=MakoTemplateEngine)
         """
         return None
@@ -271,7 +266,23 @@ class EsmeraldAPISettings(BaseSettings):
                 def middleware(self) -> List[Middleware]:
                     return [EsmeraldMiddleware]
         """
-        return None
+        return []
+
+    @property
+    def scheduler_class(self) -> SchedulerType:
+        """
+        Scheduler class to be used within the application.
+        """
+        if not self.enable_scheduler:
+            return None
+
+        try:
+            from asyncz.schedulers import AsyncIOScheduler
+        except ImportError:
+            raise ImportError(
+                "The scheduler must be installed. You can do it with `pip install esmerald[schedulers]`"
+            )
+        return AsyncIOScheduler
 
     @property
     def scheduler_tasks(self) -> Dict[str, str]:
@@ -339,28 +350,28 @@ class EsmeraldAPISettings(BaseSettings):
         """
         Returns the default interceptors of Esmerald.
         """
-        return None
+        return []
 
     @property
     def permissions(self) -> List[Permission]:
         """
         Returns the default permissions of Esmerald.
         """
-        return None
+        return []
 
     @property
     def dependencies(self) -> Dependencies:
         """
         Returns the dependencies of Esmerald main app.
         """
-        return None
+        return {}
 
     @property
     def exception_handlers(self) -> ExceptionHandlers:
         """
         Default exception handlers to be loaded when the application starts
         """
-        return None
+        return {}
 
     @property
     def on_startup(self) -> List[LifeSpanHandler]:
