@@ -37,7 +37,7 @@ from esmerald.exceptions import ImproperlyConfigured
 from esmerald.injector import Inject
 from esmerald.permissions.utils import continue_or_raise_permission_exception
 from esmerald.requests import Request
-from esmerald.responses import ORJSONResponse, Response, UJSONResponse
+from esmerald.responses import JSONResponse, Response
 from esmerald.routing.views import APIView
 from esmerald.transformers.model import TransformerModel
 from esmerald.transformers.signature import SignatureFactory
@@ -240,7 +240,6 @@ class BaseResponseHandler:
         self,
         cookies: "ResponseCookies",
         headers: Optional["ResponseHeaders"] = None,
-        media_type: Optional["MediaType"] = MediaType.TEXT,
     ) -> "AsyncAnyCallable":
         """Creates an handler for Starlette Responses."""
 
@@ -257,8 +256,6 @@ class BaseResponseHandler:
             for cookie in _cookies:
                 data.set_cookie(**cookie)
 
-            data.media_type = media_type
-
             for header, value in _headers.items():
                 data.headers[header] = value
             return data  # type: ignore
@@ -278,8 +275,7 @@ class BaseResponseHandler:
 
             data = await self.get_response_data(data=data)
             _cookies = self.get_cookies(cookies, [])
-            # Making sure ORJSONResponse and JSONResponse are properly handled
-            if isinstance(data, (JSONResponse, ORJSONResponse, UJSONResponse)):
+            if isinstance(data, JSONResponse):
                 response = data
                 response.status_code = status_code
                 response.background = background
@@ -399,7 +395,7 @@ class BaseResponseHandler:
                 )
             elif is_class_and_subclass(
                 self.signature.return_annotation,
-                (JSONResponse, ORJSONResponse, UJSONResponse),
+                JSONResponse,
             ):
                 handler = self.json_response_handler(
                     status_code=self.status_code, cookies=cookies, headers=headers
@@ -414,7 +410,6 @@ class BaseResponseHandler:
             elif is_class_and_subclass(self.signature.return_annotation, StarletteResponse):
                 handler = self.starlette_response_handler(
                     cookies=cookies,
-                    media_type=self.media_type,
                     headers=headers,
                 )
             else:
