@@ -11,30 +11,35 @@ from typing import (
 )
 
 import httpx  # noqa
+from starlette.testclient import TestClient  # noqa
+
 from esmerald.applications import Esmerald
 from esmerald.conf import settings  # noqa
 from esmerald.utils.crypto import get_random_secret_key
-from starlette.testclient import TestClient  # noqa
 
 if TYPE_CHECKING:
+    from typing_extensions import Literal
+
     from esmerald.config import (
         CORSConfig,
         CSRFConfig,
         OpenAPIConfig,
         SessionConfig,
         StaticFilesConfig,
-        TemplateConfig,
     )
+    from esmerald.interceptors.types import Interceptor
     from esmerald.permissions.types import Permission
     from esmerald.types import (
         APIGateHandler,
         Dependencies,
+        DictStr,
         ExceptionHandlers,
         LifeSpanHandler,
         Middleware,
         SchedulerType,
+        SettingsType,
+        TemplateConfig,
     )
-    from typing_extensions import Literal
 
 
 class EsmeraldTestClient(TestClient):
@@ -49,15 +54,17 @@ class EsmeraldTestClient(TestClient):
         backend: "Literal['asyncio', 'trio']" = "asyncio",
         backend_options: Optional[Dict[str, Any]] = None,
         cookies: Optional[httpx._client.CookieTypes] = None,
+        headers: Optional["DictStr"] = None,
     ):
         super().__init__(
-            app,
-            base_url,
-            raise_server_exceptions,
-            root_path,
-            backend,
-            backend_options,
-            cookies,
+            app=app,
+            base_url=base_url,
+            raise_server_exceptions=raise_server_exceptions,
+            root_path=root_path,
+            backend=backend,
+            backend_options=backend_options,
+            cookies=cookies,
+            headers=headers,
         )
 
     def __enter__(self, *args: Any, **kwargs: Dict[str, Any]) -> "EsmeraldTestClient":
@@ -67,45 +74,48 @@ class EsmeraldTestClient(TestClient):
 def create_client(
     routes: Union["APIGateHandler", List["APIGateHandler"]],
     *,
-    debug: bool = settings.debug,
-    name: Optional[str] = settings.app_name,
+    settings_config: Optional["SettingsType"] = None,
+    debug: Optional[bool] = None,
+    app_name: Optional[str] = None,
     secret_key: Optional[str] = get_random_secret_key(),
-    allowed_hosts: Optional[List[str]] = settings.allowed_hosts,
-    allow_origins: Optional[List[str]] = settings.allow_origins,
+    allowed_hosts: Optional[List[str]] = None,
+    allow_origins: Optional[List[str]] = None,
     base_url: str = "http://testserver",
     backend: "Literal['asyncio', 'trio']" = "asyncio",
     backend_options: Optional[Dict[str, Any]] = None,
-    permissions: Optional[List["Permission"]] = settings.permissions,
-    dependencies: Optional["Dependencies"] = settings.dependencies,
-    middleware: Optional[List["Middleware"]] = settings.middleware,
-    csrf_config: Optional["CSRFConfig"] = settings.csrf_config,
-    exception_handlers: Optional["ExceptionHandlers"] = settings.exception_handlers,
-    openapi_config: Optional["OpenAPIConfig"] = settings.openapi_config,
-    on_shutdown: Optional[List["LifeSpanHandler"]] = settings.on_shutdown,
-    on_startup: Optional[List["LifeSpanHandler"]] = settings.on_startup,
-    cors_config: Optional["CORSConfig"] = settings.cors_config,
-    session_config: Optional["SessionConfig"] = settings.session_config,
-    scheduler_class: Optional["SchedulerType"] = settings.scheduler_class,
-    scheduler_tasks: Optional[Dict[str, str]] = settings.scheduler_tasks,
-    scheduler_configurations: Optional[
-        Dict[str, Union[str, Dict[str, str]]]
-    ] = settings.scheduler_configurations,
-    enable_scheduler: bool = settings.enable_scheduler,
+    interceptors: Optional[List["Interceptor"]] = None,
+    permissions: Optional[List["Permission"]] = None,
+    dependencies: Optional["Dependencies"] = None,
+    middleware: Optional[List["Middleware"]] = None,
+    csrf_config: Optional["CSRFConfig"] = None,
+    exception_handlers: Optional["ExceptionHandlers"] = None,
+    openapi_config: Optional["OpenAPIConfig"] = None,
+    on_shutdown: Optional[List["LifeSpanHandler"]] = None,
+    on_startup: Optional[List["LifeSpanHandler"]] = None,
+    cors_config: Optional["CORSConfig"] = None,
+    session_config: Optional["SessionConfig"] = None,
+    scheduler_class: Optional["SchedulerType"] = None,
+    scheduler_tasks: Optional[Dict[str, str]] = None,
+    scheduler_configurations: Optional[Dict[str, Union[str, Dict[str, str]]]] = None,
+    enable_scheduler: bool = None,
     raise_server_exceptions: bool = True,
-    root_path: str = "",
+    root_path: Optional[str] = "",
     static_files_config: Optional[Union["StaticFilesConfig", List["StaticFilesConfig"]]] = None,
     template_config: Optional["TemplateConfig"] = None,
-    lifespan: Optional[Callable[["Esmerald"], "AsyncContextManager"]] = settings.lifespan,
-    cookies: Optional[httpx._client.CookieTypes] = None
+    lifespan: Optional[Callable[["Esmerald"], "AsyncContextManager"]] = None,
+    cookies: Optional[httpx._client.CookieTypes] = None,
+    redirect_slashes: Optional[bool] = None,
 ) -> EsmeraldTestClient:
     return EsmeraldTestClient(
         app=Esmerald(
+            settings_config=settings_config,
             debug=debug,
             routes=cast("Any", routes if isinstance(routes, list) else [routes]),
-            name=name,
+            app_name=app_name,
             secret_key=secret_key,
             allowed_hosts=allowed_hosts,
             allow_origins=allow_origins,
+            interceptors=interceptors,
             permissions=permissions,
             dependencies=dependencies,
             middleware=middleware,
@@ -123,6 +133,7 @@ def create_client(
             template_config=template_config,
             session_config=session_config,
             lifespan=lifespan,
+            redirect_slashes=redirect_slashes,
         ),
         base_url=base_url,
         backend=backend,
